ConnIdExt

Trait ConnIdExt 

pub trait ConnIdExt {
    // Required method
    fn id(&self) -> &str;
}
Extension trait to retrieve an id generated by the ConnId handler

Required Methods

fn id(&self) -> &str

Retrieves the id for this conn. This method will panic if it is run before the ConnId handler.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<ConnLike> ConnIdExt for ConnLike
where ConnLike: AsRef<TypeSet>,